Usage
=====

.. _install:

Installation
------------

To use QPrism, the installation can be done with pip.
Since pip does not resolve the dependencies' version efficiently, please install QPrism with the following steps.

.. code-block:: console

   $ python3 -m pip install --upgrade pip

.. code-block:: console

   $ pip install -r https://raw.githubusercontent.com/aid4mh/QPrism/main/requirements.txt

.. code-block:: console

   $ pip install --no-deps -i https://test.pypi.org/simple/ QPrism==0.1.7

Examples
----------------

To be filled in after publish the package and finalized the demos

